@@ -34,7 +34,7 @@ except AttributeError:
             pass
 
 __author__ = 'Alec Thomas <alec@swapoff.org>'
-__version__ = '0.9.0'
+__version__ = '0.9.1'
 __version_tag__ = ''
 
 log = logging.getLogger('injector')
@@ -970,7 +970,7 @@ def inject(**bindings):
 
         original_keys = tuple(bindings.keys())
 
-        for k in bindings:
+        for k in list(bindings.keys()):
             bindings[k.lstrip('_')] = bindings.pop(k)
 
         @inject(**bindings)
